JOKER="*"
INFIX_LETTERS=u"اتوي"
#النون هل هي من حروف الحشو
MAX_PREFIX=5;
MAX_SUFFIX=6;



#------------------------------
# PREFIXES_LIST
#------------------------------
PREFIXES_LIST=[
u'ءأ',
u'ا',
u'ات',
u'است',
u'ال',
u'الا',
u'الاست',
u'الان',
u'الأ',
u'الإ',
u'الت',
u'اللا',
u'الم',
u'المت',
u'المتم',
u'المست',
u'المن',
u'ان',
u'اي',
u'أ',
u'أال',
u'أأ',
u'أب',
u'أبال',
u'لبال',
u'أت',
u'أف',
u'أفأ',
u'أفا',
u'أفال',
u'أفب',
u'أفبال',
u'أفت',
u'أفن',
u'أل',
u'ألل',
u'أو',
u'أن',
u'أوا',
u'أوال',
u'أولل',
u'أي',
u'إ',
u'است',
u'ب',
u'باست',
u'بال',
u'بالا',
u'بالاست',
u'بالان',
u'بالأ',
u'بالإ',
u'بالت',
u'بالم',
u'بالمت',
u'بالمست',
u'بان',
u'بأ',
u'بإ',
u'بت',
u'بم',
u'بمست',
u'ت',
u'تال',
u'تت',
u'تست',
u'تن',
##u'س',
u'سأ',
u'ست',
u'سن',
u'سنت',
u'سي',
u'سيت',
u'ف',
u'فا',
u'فاست',
u'فال',
u'فالا',
u'فالاست',
u'فالأ',
u'فالت',
u'فالم',
u'فالمست',
u'فان',
u'فأ',
u'فإ',
u'فب',
u'فبال',
u'فبالم',
u'فت',
u'فتست',
u'فس',
u'فسأ',
u'فست',
u'فسن',
u'فسي',
u'فك',
u'فل',
u'فلأ',
u'فلل',
u'فللم',
u'فلن',
u'فلي',
u'فليست',
u'فم',
u'فن',
u'فنت',
u'فو',
u'فوال',
u'في',
u'فيت',
u'فيست',
u'فين',
u'ك',
u'كاست',
u'كال',
u'كالا',
u'كالاست',
u'كالان',
u'كالت',
u'كالم',
u'كالمت',
u'كالمست',
u'كم',
u'كمست',
u'ل',
u'لا',
u'لاست',
u'لال',
u'لان',
u'لأ',
u'لأست',
u'لإ',
u'لت',
u'لل',
u'للا',
u'للاست',
u'للان',
u'للإ',
u'للاست',
u'للت',
u'للم',
u'للمت',
u'للمست',
u'لم',
u'لمست',
u'لن',
u'لي',
u'ليت',
u'ليست',
u'م',
u'مت',
u'مست',
u'من',
u'ن',
u'نت',
u'نست',
u'و',
u'وا',
u'وات',
u'واست',
u'وال',
u'والا',
u'والاست',
u'والان',
u'والأ',
u'والإ',
u'والت',
u'والم',
u'والمت',
u'والمست',
u'والمن',
u'وان',
u'وأ',
u'وأست',
u'وإ',
u'وب',
u'وبال',
u'وبالأ',
u'وبالت',
u'وبالم',
u'وبالمت',
u'وبإ',
u'وبت',
u'وبم',
u'وت',
u'وتت',
u'وسأ',
u'وست',
u'وسن',
u'وسي',
u'وك',
u'وكال',
u'ول',
u'ولأ',
u'ولت',
u'ولتست',
u'ولل',
u'وللا',
u'وللاست',
u'وللت',
u'وللم',
u'وللمت',
u'ولم',
u'ولن',
u'ولي',
u'وليت',
u'وم',
u'ومت',
u'ومست',
u'ومن',
u'ون',
u'وي',
u'ويت',
u'ويست',
u'وين',
u'ي',
u'يا',
u'يال',
u'يالل',
u'يت',
u'يست',
u'ين',
]

#------------------------------
#SUFFIXES_LIST
#------------------------------
SUFFIXES_LIST=[
u'ا',
u'اءك',
u'اءكم',
u'كموه',
u'كموها',
u'اءكما',
u'اءكن',
u'اءنا',
u'اءه',
u'اءها',
u'اءهم',
u'اءهما',
u'اءهن',
u'اءي',
u'ائك',
u'ائكم',
u'ائكما',
u'ائكن',
u'ائنا',
u'ائه',
u'ائها',
u'ائهم',
u'ائهما',
u'ائهن',
u'ائي',
u'ات',
u'اتك',
u'اتكم',
u'اتكما',
u'اتكن',
u'اتنا',
u'اته',
u'اتها',
u'اتهم',
u'اتهما',
u'اتهن',
u'اتي',
u'اتيات',
u'اتيان',
u'اتية',
u'اتيه',
u'اتيون',
u'اتيين',
u'اك',
u'اكما',
u'اكن',
u'ان',
u'انا',
u'انات',
u'اناتك',
u'اناتكم',
u'اناتكما',
u'اناتكن',
u'اناتنا',
u'اناته',
u'اناتها',
u'اناتهم',
u'اناتهما',
u'اناتهن',
u'اناتي',
u'انة',
u'انك',
u'انكم',
u'انكما',
u'انكن',
u'اننا',
u'انني',
u'انه',
u'انها',
u'انهم',
u'انهما',
u'انهن',
u'اني',
u'انيات',
u'انيان',
u'انية',
u'انيتك',
u'انيتكم',
u'انيتكما',
u'انيتكن',
u'انيتنا',
u'انيته',
u'انيتها',
u'انيتهم',
u'انيتهما',
u'انيتهن',
u'انيتي',
u'انيون',
u'انيين',
u'اها',
u'اهما',
u'اهن',
u'اوات',
u'اوي',
u'اوية',
u'اي',
u'ت',
u'ة',
u'تاك',
u'تاكم',
u'تاكما',
u'تاكن',
u'تان',
u'تانا',
u'تاني',
u'تاه',
u'تاها',
u'تاهم',
u'تاهما',
u'تاهن',
u'تاي',
u'تك',
u'تكم',
u'تكما',
u'تكن',
u'تم',
u'تما',
u'تمانا',
u'تماني',
u'تماه',
u'تماها',
u'تماهم',
u'تماهما',
u'تماهن',
u'تمونا',
u'تموني',
u'تموه',
u'تموها',
u'تموهم',
u'تموهما',
u'تموهن',
u'تن',
u'تنا',
u'تني',
u'ته',
u'تها',
u'تهم',
u'تهم',
u'تهما',
u'تهن',
u'تيَّ',
u'تي',
u'تيك',
u'تيكم',
u'تيكما',
u'تيكن',
u'تين',
u'تينا',
u'تيه',
u'تيها',
u'تيهم',
u'تيهما',
u'تيهن',
u'ك',
u'ك',
u'كم',
u'كم',
u'كما',
u'كن',
u'ن',
u'نا',
u'ناك',
u'ناكم',
u'ناكما',
u'ناكموه',
u'ناكن',
u'ناه',
u'ناها',
u'ناهم',
u'ناهما',
u'ناهن',
u'نك',
u'نكم',
u'نكما',
u'نكن',
u'ننا',
u'نني',
u'نه',
u'نها',
u'نهم',
u'نهما',
u'نهن',
u'ني',
u'نيها',
u'ه',
u'ه',
u'ها',
u'هم',
u'هما',
u'هن',
u'وا',
u'وات',
u'وانية',
u'وك',
u'وكم',
u'وكما',
u'وكن',
u'ون',
u'ونا',
u'ونك',
u'ونكم',
u'ونكما',
u'ونكن',
u'وننا',
u'ونني',
u'ونه',
u'ونها',
u'ونهم',
u'ونهما',
u'ونهن',
u'وني',
u'وه',
u'وها',
u'وهم',
u'وهما',
u'وهن',
u'ي',
u'يات',
u'ياتك',
u'ياتكم',
u'ياتكما',
u'ياتكن',
u'ياتنا',
u'ياته',
u'ياتها',
u'ياتهم',
u'ياتهن',
u'ياتهها',
u'ياتي',
u'يان',
u'ية',
u'يتان',
u'يتك',
u'يتكم',
u'يتكما',
u'يتكن',
u'يتنا',
u'يته',
u'يتها',
u'يتهم',
u'يتهما',
u'يتهن',
u'يتي',
u'يتيا',
u'يتيان',
u'يتين',
u'يك',
u'يكم',
u'يكم',
u'يكما',
u'يكن',
u'ين',
u'ينا',
u'يننا',
u'ينني',
u'ينه',
u'ينها',
u'ينهم',
u'ينهما',
u'ينهن',
u'يني',
u'يه',
u'يها',
u'يهم',
u'يهم',
u'يهما',
u'يهن',
u'يون',
u'يي',
u'يين',
]

#-------------------
#
#-------------------
VERBAL_PREFIX_LIST=[
u'ءأ',
u'ا',
u'ات',
u'است',
u'ان',
u'اي',
u'أ',
u'أأ',
u'أت',
u'أف',
u'أفأ',
u'أفا',
u'أفت',
u'أفن',
u'أل',
u'أو',
u'أن',
u'أوا',
u'أي',
u'إ',
u'است',
u'ت',
u'تت',
u'تست',
u'تن',
##u'س',
u'سأ',
u'ست',
u'سن',
u'سنت',
u'سي',
u'سيت',
u'ف',
u'فا',
u'فاست',
u'فان',
u'فأ',
u'فإ',
u'فت',
u'فتست',
u'فس',
u'فسأ',
u'فست',
u'فسن',
u'فسي',
u'فل',
u'فلأ',
u'فلن',
u'فلي',
u'فليست',
u'فن',
u'فنت',
u'فو',
u'في',
u'فيت',
u'فيست',
u'فين',
u'ل',
u'لا',
u'لاست',
u'لان',
u'لأ',
u'لأست',
u'لإ',
u'لت',
u'لن',
u'لي',
u'ليت',
u'ليست',
u'ن',
u'نت',
u'نست',
u'و',
u'وا',
u'وات',
u'واست',
u'وان',
u'وأ',
u'وأست',
u'وإ',
u'وت',
u'وتت',
u'وسأ',
u'وست',
u'وسن',
u'وسي',
u'ول',
u'ولأ',
u'ولت',
u'ولتست',
u'ولن',
u'ولي',
u'وليت',
u'ون',
u'وي',
u'ويت',
u'ويست',
u'وين',
u'ي',
u'يا',
u'يت',
u'يست',
u'ين',
]


#------------------------------
# PREFIXES_LIST
#------------------------------
NOMINAL_PREFIXES_LIST=[
u'ءأ',
u'ا',
u'ات',
u'است',
u'ال',
u'الا',
u'الاست',
u'الان',
u'الأ',
u'الإ',
u'الت',
u'اللا',
u'الم',
u'المت',
u'المتم',
u'المست',
u'المن',
u'ان',
u'أ',
u'أال',
u'أأ',
u'أب',
u'أبال',
u'لبال',
u'أت',
u'أف',
u'أفأ',
u'أفا',
u'أفال',
u'أفب',
u'أفبال',
u'أفت',
u'أل',
u'ألل',
u'أو',
u'أوا',
u'أوال',
u'أولل',
u'إ',
u'است',
u'ب',
u'باست',
u'بال',
u'بالا',
u'بالاست',
u'بالان',
u'بالأ',
u'بالإ',
u'بالت',
u'بالم',
u'بالمت',
u'بالمست',
u'بان',
u'بأ',
u'بإ',
u'بت',
u'بم',
u'بمست',
u'ت',
u'تال',
u'ف',
u'فا',
u'فاست',
u'فال',
u'فالا',
u'فالاست',
u'فالأ',
u'فالت',
u'فالم',
u'فالمست',
u'فان',
u'فأ',
u'فإ',
u'فب',
u'فبال',
u'فبالم',
u'فت',
u'فك',
u'فل',
u'فلأ',
u'فلل',
u'فللم',
u'فم',
u'فو',
u'فوال',
u'ك',
u'كاست',
u'كال',
u'كالا',
u'كالاست',
u'كالان',
u'كالت',
u'كالم',
u'كالمت',
u'كالمست',
u'كم',
u'كمست',
u'ل',
u'لا',
u'لاست',
u'لال',
u'لان',
u'لأ',
u'لإ',
u'لت',
u'لل',
u'للا',
u'للاست',
u'للان',
u'للإ',
u'للاست',
u'للت',
u'للم',
u'للمت',
u'للمست',
u'لم',
u'لمست',
u'م',
u'مت',
u'مست',
u'من',
u'و',
u'وا',
u'وات',
u'واست',
u'وال',
u'والا',
u'والاست',
u'والان',
u'والأ',
u'والإ',
u'والت',
u'والم',
u'والمت',
u'والمست',
u'والمن',
u'وان',
u'وأ',
u'وإ',
u'وب',
u'وبال',
u'وبالأ',
u'وبالت',
u'وبالم',
u'وبالمت',
u'وبإ',
u'وبت',
u'وبم',
u'وت',
u'وك',
u'وكال',
u'ول',
u'ولأ',
u'ولت',
u'ولل',
u'وللا',
u'وللاست',
u'وللت',
u'وللم',
u'وللمت',
u'ولم',
u'وم',
u'ومت',
u'ومست',
u'ومن',
]



# -*- coding: UTF-8 -*-
textlist=[
	u"""بحمد الله ومنّته، أطلقنا اليوم واجهة سطح المكتب  لبرنامج مشكال لتشكيل النصوص العربية آليا مفتوح المصدر،
  وبهذا يتوفر حاليا تطبيقان للبرنامج على الوب .
 وعلى سطح المكتب لنظام وندوز. وسيتوفر لنظام لينكس.	
	""",
	u"""أسطورة أزمة المحتوى العربي على الإنترنت

حين تجرب، غير ما مرة، البحث بالعربية في الإنترنت ولا تجد ما يشبع حاجتك، تعرف بأن المحتوى العربي على الإنترنت يعاني نقصا فظيعا. لا تحتاج إلى جوجل أو غيرها لإخبارك بأن نسبة 1% التي يمثلها المحتوى العربي من مجموع المحتوى على الإنترنت، نسبة ضئيلة جدا. أنت تدرك ذلك منذ زمن، كما تدرك أنه قد مرت سنوات منذ سمعت أول مرة بأن المحتوى العربي على الإنترنت بالكاد يمثل تلك النسبة الهزيلة، ولا شيء تغير طيلة تلك السنوات. الكثير من الحبر سال حول الموضوع، وكثير من المؤتمرات انعقدت دون فائدة. المأساة أنك لو تتبعت تفاصيل تلك المؤتمرات التي تتحدث عن أزمة المحتوى العربي، لوجدت كل المتحدثين فيها يرطنون حول الموضوع بالانجليزية. ولا شك، أنك لو حاولت تبادل الحديث مع أحدهم، ولو في الشارع في موضوع عام، لما وجدته قادرا على تركيب جملة عربية خالصة لا تدخلها كلمات إنجليزية -أو فرنسية- بمناسبة أو دونها.
محمد الساحلي
	
	""",
	u"""	أهم ميزة لمشكال أنه يقترح تشكيلا آليا للنص، ومن ثمّ يمكن للمستخدم أن يصحح التشكيل، إذا وجد به خطأ، أو لم يكن المقصود كذلك, وهذه الميزة تجعل من الإصدار الحالي التجريبي مساعدا للتشكيل أكثر من كونه تشكيلا آليا,
	""",
	u"""تشكيل النصوص العربية أهم مسائل معالجة اللغة العربية، بلوغه يقتضي تجاوز عقبات عديدة، وقد أهمّت هذه المسألة الكثير من الباحثين، وحتى الشركات	
	""",
	u"""	أهم ميزة لمشكال أنه يقترح تشكيلا آليا للنص، ومن ثمّ يمكن للمستخدم أن يصحح التشكيل، إذا وجد به خطأ، أو لم يكن المقصود كذلك, وهذه الميزة تجعل من الإصدار الحالي التجريبي مساعدا للتشكيل أكثر من كونه تشكيلا آليا,
	""",
	u"""
يقدم البرنامج وظيفة نادرة لخدمة اللغة العربية ( لغة القرآن ) فهو يساعد المستخدم لتشكيل النص ، حيث يقوم البرنامج بمعالجة النص بعد وضعه في المربع المخصص له ووضع التشكيل عليه ( الفتحة والضمة والكسرة و.... الخ ) ومن ثم يمكن للمستخدم النقر على أي كلمة لتصحيح التشكيل وتغييره إذا كان فيه خطأ

البرنامج هو مساعد لعملية التشكيل أكثر منه مشكل آلي ، حيث لا غنى عن معرفة المستخدم في تصحيح بعض الأخطاء وتعديل التشكيل في بعض الكلمات ، لكن مسألة التشكيل ستكون سهلة وسريعة ومريحة جدا للمستخدم العربي بواسطة هذا البرنامج
	
	"""
,

	u"الولد مريض.",
	u"الطائر فوق الشجرة.",
	u"البستان جميل.",
	u"قطف محمد زهرة.",
	u"الشمس طالعة.",
	u"شم علي وردة.",
	u"يعيش السمك في الماء.",
	u"يكثر النخيل في مصر.",
	u"السماء ممطرة.",
	u"الحديقة جميلة.",
	u"يقطف علي الأزهار.",
	u"يلعب الغلمان بالكرة.",
	u"ينزل المطر من السماء .",
	u"يسير السحاب.",
	u"تطلع الشمس .",
	u"تسير السفن في البحار.",
	u"تجف الأرض .",
	u"يشتد البرد في الجبال.",
	u"الثوب نظيف.",
	u"القطار سريع.",
	u"العصفور في القفص .",
	u"الولد يأكل الفاكهة .",
	u"الثور يحرث الأرض .",
	u"القمر في السماء.",
	u"ركب إبراهيم الحصان .",
	u"سمعت النصيحة.",
	u"يداعب إسماعيل القط.",
	u"يسطع النور في الحجرة .",
	u"يحصد الفلاح القمح.",
	u"تجري السفينة على الماء.",
	u"تأكل الشاة فولا وشعيرا .",
	u"هل تحب السفر.",
	u"فريد يجري في الشارع.",
	u"يحب الولد البرتقال.",
	u"علي يركب الحمار.",
	u"يحترق الحطب.",
	u"الكلب ينام في البستان.",
	u"يتسلق الغلمان الجبل.",
	u"افترس الذئب كبشا.",
	u"يسبح الأولاد في البحار.",
	u"البستاني يجمع الأزهار.",
	u"المداد في الدواة.",
	u"الثعلب يأكل الدجاج.",
	u"الحديد يذوب في النار.",
	u"يفتح محمد الباب.",
	u"الثمر يتساقط على الأرض.",
	u"يشتري التاجر القطن.",
	u"يزرع الفلاح القصب.",
	u"تصنع الأحذية من الجلد.",
	u"يقرأ سعيد الكتاب.",
	u"العصفور يغرد على الشجرة.",
	u"يدخل الهواء في الحجرة.",
	u"يذهب العمال إلى المصنع.",
	u"العصفور مسجون في القفص.",
	u"تبيض الدجاجة.",
	u"يقرأ محمد كتابا.",
	u"يطيع أحمد أباه.",
	u"الحصان يجر العربة.",
	u"يشتد الحر في الصيف.",
	u"الفأر يخاف من الهر.",
	u"الحصان يأكل الشعير.",
	u"المريض يرجو الشفاء.",
	u"الولد يلعب بالكرة.",
	u"كسر محمود الغصن.",
	u"يصنع النجار بابا.",
	u"الطبيب يعالج المريض.",
	u"الخادم يفتح النافذة.",
	u"يسبح الغلام في النهر.",
	u"يعود الغريب إلى بلده.",
	u"يذهب التلميذ إلى المدرسة.",
	u"نام الطفل على السرير.",
	u"قطعت الحبل بالسكين.",
	u"يرضى المعلم عن التلميذ المؤدب.",
	u"جرى الكلب.",
	u"وقف الرجل.",
	u"دقت الساعة.",
	u"جاءت البنت.",
	u"ضاع الكتاب.",
	u"باضت الدجاجة.",
	u"أغسل يدي.",
	u"ينبح الكلب.",
	u"ألبس ثيابي.",
	u"ينتبه الحارس.",
	u"يلعب بالكرة.",
	u"تأكل البنت.",
	u"نمشي في الحقول.",
	u"تذبل الوردة.",
	u"العب بالكرة.",
	u"نم مبكرا.",
	u"أطعم قطك.",
	u"تمهل في السير.",
	u"نظف ثيابك.",
	u"أجد مضغ الطعام.",
	u"جنى الفلاح قطنه وباعه ثم اشترى ببعض ثمنه ما يحتاج إليه.",
	u"نظر الطفل إلى الطائر وهو يحلق في السماء.",
	u"هبت العواصف ليلا فأطفأت المصابيح واقتلعت الأشجار.",
	u"سطا الذئب على الغنم فافترس واحدة وفر هاربا.",
	u"ادخل البستان ومتع نفسك بمنظره ، ولا تعبث بأزهاره وثماره.",
	u"لا تكثر من الكلام ، ولا تنطق بما لا تعلم.",
	u"اغسل يديك قبل الأكل وبعده ، ونظف أسنانك ، ولا تدخل الطعام على الطعام.",
	u"الفأرة تخاف من القط.",
	u"الدجاجة تبيض كل يوم بيضة.",
	u"الكلب يركض وراء صاحبه.",
	u"الأم تطعم أولادها.",
	u"الولد أراد الجلوس.",
	u"الخادم نظف الغرفة.",
	u"الرجل سبح في النهر.",
	u"علي سافر إلى فرنسا.",
	u"سار القطار.",
	u"مرض الغلام.",
	u"طار الصقر.",
	u"نزل المطر.",
	u"سافر والدي.",
	u"عطش الزرع .",
	u"يغرد العصفور.",
	u"يثمر البستان.",
	u"يبيع التاجر البن.",
	u"يغسل الولد يديه.",
	u"يجني الفلاح القطن.",
	u"أحترم المعلم.",
	u"أقرأ في الكتاب.",
	u"أحفظ الدرس.",
	u"أشتغل في الحديقة.",
	u"أنظف الحذاء.",
	u"أنطق بالصدق.",
	u"طار العصفور.",
	u"يعوم السمك.",
	u"جرى الحصان.",
	u"يلسع البعوض.",
	u"لعب الولد.",
	u"تأكل البنت.",
	u"حضر الغائب.",
	u"يطير الذباب.",
	u"فاض النهر.",
	u"يربح التاجر.",
	u"شد التلميذ الحبل.",
	u"يربح السابق جائزة.",
	u"طوت البنت الثوب.",
	u"يصيد الثعلب دجاجة.",
	u"أكل الذئب الخروف.",
	u"يبيع القصاب اللحم.",
	u"مزق الغلام الورق.",
	u"صنع النجار كرسيا.",
	u"حلبت الفتاة البقرة.",
	u"رمى الصياد الشبكة.",
	u"أيقظ الرعد النائم.",
	u"طبخت المرأة الطعام.",
	u"أكل الحمار الفول.",
	u"أبصر الرجل الهلال.",
	#نعت
	u" هذا كتاب مفيد .",
	u"قرأت كتابا مفيدا .",
	u"نظرت في كتاب مفيد .",
	u"هذا ميدان فسيح .",
	u"رأيت ميدانا فسيحا .",
	u"جريت في ميدان فسيح .",
	u"تفتحت الوردة الجميلة .",
	u"قطفت الوردة الجميلة .",
	u"نظرت إلى الوردة الجميلة .",
	u"الولد المهذب يحبه أبوه .",
	u"لا تشرب الماء الراكد .",
	u"الحذاء الجديد يضر القدم .",
	u"أكثر من القراءة في الكتب النافعة , زرت ضاحية بديعة.",
	u"يضر الصديق الكاذب صديقه .",
	u"للجمل عنق طويل .",
	u"عدو عاقل خير من صديق جاهل .",
	u"تنافسوا في العمل الصالح .",
	u"يحب الناس الحاكم العادل .",
	u"وضعت الصورة في إطار بديع .",
	u"الأكل الكثير يضر المعدة .",
	u"أكره السير في الطرق المزدحمة .",
	u"تحمل الشجرة ثمارا ناضجة .",
	u"في السماء نجوم لامعة .",
	u"للطاووس ريش جميل .",
	u"أرى في الجو سحابا كثيفا .",
	u"ربح التاجر الأمين .",
	u"يقرأ علي كتابا مفيدا .",
	u"نزل من السماء مطر غزير .",
	u"يلبس علي حذاء واسعا .",
	u"يكثر النخل في البساتين المثمرة .",
	#المبتدا والخبر 
	u"التفاحة حلوة .",
	u"الصورة جميلة .",
	u"القطار سريع .",
	u"النظافة واجبة .",
	u"الجري مفيد .",
	u"الأرض مستديرة .",
	u"الدواة مملوءة .",
	u"الهواء متجدد .",
	u"الحذاء جديد .",
	u"المزاح مضر .",
	u"التاجر أمين .",
	u"الحديقة فسيحة .",
	u"المعلم حاضر .",
	u"الفقير محتاج .",
	u"الشجرة مثمرة .",
	#الجملة الفعلية
	u" يفترس النمر .",
	u"تنضج الفاكهة .",
	u"يحضر المسافر .",
	u"يشتد الحر .",
	u"يسبح السمك .",
	u"يندم الكسلان .",
	u"السيارة سريعة .",
	u"القط ألوف .",
	u"لمع البرق .",
	u"يشتد البرد .",
	u"عوى الذئب .",
	u"اقطف الوردة .",
	u"خذ الكتاب .",
	#الجملة الاسمية 
	u"الدار واسعة .",
	u"الشارع مزدحم .",
	u"الجو معتدل .",
	u"الطريقة ضيقة .",
	u"الغبار ثائر .",
	u"الفأرة مختبئة .",
	u"الماء رائق .",
	u"يسرج الخادم الحصان .",
	u"يسقط الخادم .",
	u"الزجاج مكسور .",
	u"البرد قارس .",
	u"القط جائع .",
	u"يشتد الحر في الصيف .",
	u"جنى الفلاح القطن .",
	u"يجول التاجر في البلاد .",
	u"النوافذ مفتوحة .",
	u"تزدحم المدينة بالسكان .",
	u"الولد نائم .",
	u"الكتاب نافع .",
	u"البحر هائج .",
	u"الشمس مشرقة .",
	u"المطر كثير .",
	u"الحجرة مظلمة .",
	u"ضاع المفتاح .",
	u"يثمر البستان .",
	u"أسرع القطار .",
	u"يغرد الطائر .",
	u"زاد النيل .",
	u"يضيء المصباح .",
	u"ما شكل البرتقالة ؟ ما لونها ؟.", 
	u"هل أكلت برتقالة ؟ كيف وجدت طعمها ؟ أناعمة هي أم خشنة ؟.", 
	u"بكم تشتري البرتقالة ؟.",
	#نصب الفعل المضارع 
	u"أريد أن أجيد السباحة .",
	u"أرجو أن يعتدل الجو .",
	u"لن أكتب .",
	u"لن يفوز الكسلان .",
	u"سرني أن تزورنا .",
	u"لن أضرب القط .",
	u"إذن تقيم عندنا .",
	u"إذن تربح تجارتك .",
	u"جئت كي أتعلم .",
	u"خرجت كي أتنزه .",
	u"أتعلم كي أخدم الوطن .",
	u"لن يبيع أبي حصانه.",
	u"هززت الشجرة كي يسقط ثمرها .",
	u"لا يجوز للإنسان أن يجلس في مجرى الهواء .",
	u"فتحت نوافذ الجحرة كي يتجدد هواؤها .",
	u"كن مؤدبا كي تكون محبوبا .",
	u"يشتغل الإنسان بالنهار وينام بالليل .",
	u"يجب عليك أن تنظف أسنانك كل يوم .",
	u"سأعتاد التبكير في النوم ، إذن يصح بدنك .",
	u"يقرأ سعيد في الضوء الضعيف .",
	u"يتعب الإنسان في صغره كي يرتاح في كبره .",
	u"يسرني أن تحضر .",
	u"يأكل الإنسان كي ينمو .",
	u"الحسود لن يسود .",
	u"على المسافر أن يتزود .",
	u"اشتريت منزلا كي أسكنه .",
	u"إن عدت إلى الذنب فلن أسامحك .",
	u"يحرث الفلاح الأرض كي يزرعها .",
	u"يرغب التاجر في أن يربح .",
	u"يؤلم العين أن تنظر إلى الشمس .",
	u"التلميذ الكسلان لن ينجح .",
	u"يصدق التاجر كي يرضي الله .",
	u"تبنى السجون كي يدخلها المجرمون .",
	u"لا يستطيع الأعمى أن يقرأ المكتوب .",
	u"أحب أن أسافر .",
	u"أسرعت كي أدرك القطار .",
	u"جئت كي أسلم عليك .",
	u"يؤلمني أن تعذب الحيوان .",
	u"يسرني أن أنجح .",
	u"أطاع كي يحبه أبوه .",
	u"لن يعود الغائب .",
	u"المذنب لن يعود إلى ذنبه .",
	u"محمد لن يتأخر في الصباح .",
	u"أخوك لن يتعرض للبرد .",
	u"لن أسافر وحدي .",
	u"لن أبطئ في المشي .",
	u"جلس الولد كي يستريح .",
	u"إذن يذهب التعب .",
	# جزم الفعل المضارع 
	u"لم يحفظ محمد درسه .",
	u"لا تأكل وأنت شبعان .",
	u"لم ينقطع نزول المطر .",
	u"لا تكثر من الضحك .",
	u"لم يقبض أحد على اللص .",
	u"لا تسرع في السير .",
	u"إن تفتح نوافذ الحجرة يتجدد هواؤها .",
	u"إن تجلس في مجرى الهواء تمرض .",
	u"إن يسافر أخوك تسافر معه .",
	u"غامت السماء ولم تمطر .",
	u"إن تقرب من النار تشعر بحرارتها .",
	u"لم يحضر علي البارحة .",
	u"إن تتلف شيئا لغيرك تدفع ثمنه .",
	u"لا تتعود كثرة المزاح .",
	u"إن تضرب قطا يخمشك .",
	u"لا تشرب وأنت تعب .",
	u"لا تبلع طعاما قبل أن تجيد مضغه .",
	u"العصفور لم يغرد .",
	u"مشيت كثيرا ولم أتعب .",
	u"لم يثمر البستان .",
	u"القطار لم يتأخر عن موعده .",
	u"لم يحضر محمد مع أخيه .",
	u"لم أتعلم السباحة .",
	u"لم أضيع وقتا في اللعب .",
	u"الفلاح لم يحلب بقرته .",
	u"لا تلوث يديك بالمداد .",
	u"لا تتلف أثاث المنزل .",
	u"لا تضرب من هو أصغر منك .",
	u"لا تأخذ ما ليس لك .",
	u"لا تشرب بعد الجري .",
	u"لا تلبس الملابس الضيقة .",
	u"لم يسافر محمد .",
	u"لا ترافق الأشرار .",
	u"لم يلعب الولد .",
	u"لا تعذب الحيوان .",
	u"لم يأكل القط .",
	u"لا تهمل دروسك .",
	u"لم ينكسر الزجاج .",
	u"لم يرسل الغائب رسالة إلى أهله .",
	u"لم يحرث الفلاح أرضه .",
	u"لا تشرب الماء الكدر .",
	u"لا تكذب .",
	#كان وأخواتها 
	u"الزحام شديد .",
	u"كان الزحام شديدا .",
	u"البيت نظيف .",
	u"كان البيت نظيفا .",
	u"الثوب قصير .",
	u"صار الثوب قصيرا .",
	u"البرد قارس .",
	u"صار البرد قارسا .",
	u"الخادم قوي .",
	u"ليس الخادم قويا .",
	u"العامل نشيط .",
	u"ليس العامل نشيطا .",
	u"النهم مريض .",
	u"أصبح النهم مريضا .",
	u"الجو ممطر .",
	u"أصبح الجو ممطرا .",
	u"العامل متعب .",
	u"أمسى العامل متعبا .",
	u"الزهر ذابل .",
	u"أمسى الزهر ذابلا .",
	u"الغمام كثيف .",
	u"أضحى الغمام كثيفا .",
	u"الشارع مزدحم .",
	u"أضحى الشارع مزدحما .",
	u"المطر غزير .",
	u"ظل المطر غزيرا .",
	u"المصباح متقد .",
	u"بات المصباح متقدا .",
	u"المريض متألم .",
	u"بات المريض متألما .",
	u"يصبح المداد جافا .",
	u"يبيت البحر هائجا .",
	u"يظل العامل مشتغلا .",
	u"يمسي الناجح مسرورا .",
	u"يضحي الشارع مزدحما .",
	u"أصبحت الغرفة نظيفة.",
	u"باتت البحيرة هائجة .",
	u"ظلت العاملة مشتغلة .",
	u"أمست الناجحة مسرورة .",
	u"أضحت المدينة مزدحمة .",
	u"تصبح الغرفة نظيفة .",
	u"تبيت البحيرة هائجة .",
	u"تظل العاملة مشتغلة .",
	u"تمسي الناجحة مسرورة .",
	u"تضحي المدينة مزدحمة .",
	#إن وأخواتها
	u" إن الجمل صبور .",
	u"إن الهرم قديم .",
	u"علمت أن الامتحان قريب .",
	u"يسرني أن الزهرة ناضرة .",
	u"كأن الكتاب أستاذ .",
	u"كأن القمر مصباح .",
	u"البيت جديد لكن الأثاث قديم .",
	u"شبت النار لكن الخسائر قليلة .",
	u"ليت الفاكهة ناضجة .",
	u"ليت القمر طالع .",
	u"لعل الكتاب رخيص.",
	u"لعل المريض نائم .",
	]



#!/usr/bin/python
# -*- coding: UTF-8 -*-
#-------------------------------------------------------------------------------
# Name:        myrepr
# Purpose:    Used to custmize repr fucntions 
#
# Author:      Taha Zerrouki (taha.zerrouki[at]gmail.com)
#
# Created:     31-10-2011
# Copyright:   (c) Taha Zerrouki 2011
# Licence:     GPL
#-------------------------------------------------------------------------------

import repr as reprlib
import sys
class MyRepr(reprlib.Repr):
	def repr_unicode(self, obj, level):
		"Modify unicode display "
		return u"u'%s'"%obj;
		# return obj.encode('utf8');



#!/usr/bin/python
# -*- coding=utf-8 -*-
#
import re, string,sys
# from arabic_const import *
sys.path.append('mishkal/lib/');
from pyarabic.araby import *
pronouns=(
YEH,
KAF,
HEH,
KAF+MEEM,
KAF+NOON,
HEH+ALEF,
HEH+MEEM,
HEH+NOON,
NOON+ALEF,
KAF+MEEM+ALEF,
HEH+MEEM+ALEF,
);
jonction=(WAW,FEH);
prepositions=(BEH,KAF,LAM);
definition=(u''.join([ALEF,LAM]));

def generate_allforms(word,has_pronouns=True,has_jonction=True,has_preposition=True,has_definition=True,has_interrog=True):
	mylist=[word+FATHA, word+DAMMA, word+KASRA];
	temp=[];
	if has_preposition :
		for w in mylist:
			if w.endswith(KASRA):
#				temp.append(w)
				for pr in prepositions:
					temp.append(pr+"-"+w);
	mylist+=temp;
	temp=[];
	if has_jonction :
		for w in mylist:
#			temp.append(w)
			for jo in jonction:
				temp.append(jo+"-"+w);
	mylist+=temp;
	temp=[];
	if has_interrog :
		for w in mylist:
#			temp.append(w)
			temp.append(ALEF_HAMZA_ABOVE+"-"+w);
	mylist+=temp;
	temp=[];
	
	if has_pronouns:
		for word in mylist:
			for p in pronouns:
				if p==YEH and not word.endswith(KASRA):
					pass;
				else:
				# convert ALEF_mAKSURA to YEH
					if word.endswith(ALEF_MAKSURA):
						temp.append(word[:-1]+ALEF+"-"+p);
					elif word.endswith(HAMZA+KASRA):
						temp.append(word[:-2]+YEH_HAMZA+KASRA+"-"+p);
					elif word.endswith(HAMZA+DAMMA):
						temp.append(word[:-2]+WAW_HAMZA+DAMMA+"-"+p)
					else:
						temp.append(word+"-"+p);
			# add alef lam ta3rif
			if has_definition:
				temp.append(ALEF+LAM+"-"+word)
	mylist+=temp;
	return mylist;


def standardize_form(word):
    word=re.sub(u"%s-"%ALEF_MAKSURA,ALEF,word)
    word=re.sub(u"%s-"%TEH_MARBUTA,TEH,word)
    word=re.sub(u"%s-%s%s"%(LAM,ALEF,LAM),LAM+LAM,word)
    word=re.sub(u"-",'', word);
    return word;
def generate(word):
    genlist=generate_allforms(word);
    result_list=[];
    for oneword in genlist:
        result_list.append({'affixed':oneword,'standard':standardize_form(oneword)} )
    return result_list;




#!/usr/bin/python
# -*- coding=UTF-8 -*-
#------------------------------------------------------------------------
# Name:        adaat
# Purpose:    interface between library and the web interface for Adawat 
#
# Author:      Taha Zerrouki (taha.zerrouki[at]gmail.com)
#
# Created:     31-10-2011
# Copyright:   (c) Taha Zerrouki 2011
# Licence:     GPL
#-----------------------------------------------------------------------
"""
Adaat, arabic tools interface
"""
from __future__ import (absolute_import, division,
                        print_function, unicode_literals)
import sys
import os
import re
import random
from collections import Counter

import pyarabic.araby  as araby # arabic words general functions
import pyarabic.number
import pyarabic.named
import pyarabic.unshape
import pyarabic.trans

import tashaphyne.stemming 


import qalsadi.analex 
import asmai.anasem 
import sylajone.anasyn as arasyn      
import naftawayh.wordtag
import mishkal.tashkeel as ArabicVocalizer
import maskouk.collocations as colloc 

try:
    import generate
except ImportError:
    from . import generate
    
try:
    import randtext
except ImportError:
    from . import randtext
    
COMMAND_TABLE ={
  'affixate': {'action': 'Affixate',
              'help': 'generate all word forms by affixation'},
 'collocation': {'action': 'show_collocations',
                 'help': 'extract collocations from text '},
 #~ 'csv2data': {'action': 'CsvToData',
              #~ 'help': 'convert CSV columns to python data '},
 "chunk": {'action': 'chunk',
              'help': 'Extract chunks from texts'},
              
 'inverse': {'action': 'Inverse', 'help': 'inverse text'},
 'language': {'action': 'Language',
              'help': 'detect arabic and latin clauses in text'},
 'named': {'action': 'extractNamed',
           'help': 'extract named enteties from text'},
 'normalize': {'action': 'Normalize',
               'help': 'normalize letters in arabic text'},
 'num2word': {'action': 'NumberToLetters',
              'help': 'convert numeric value to words'},
 'numbered': {'action': 'extractNumbered',
              'help': 'extarct numbred clauses from text'},
 'poetry': {'action': 'Poetry',
            'help': 'format poetry texts to columns poetry'},
 'random': {'action': 'RandomText', 'help': 'get a random text'},
 'reduce': {'action': 'ReduceTashkeel',
            'help': 'strip unnecessary tashkeel from avocalized text '},
 'romanize': {'action': 'Romanize',
              'help': 'convert an arabic script text to latin representation '},
 #~ 'spell': {'action': 'SpellCheck', 'help': 'spellcheck text '},
 'stem': {'action': 'LightStemmer',
          'help': 'morphology analysis of given texts '},
 'strip': {'action': 'StripHarakat', 'help': 'remove all harakat and shadda '},
 'tashkeel': {'action': 'TashkeelText',
              'help': 'vocalize text, we recomand to use mishkal-console instead.'},
 'tokenize': {'action': 'Tokenize', 'help': 'tokenize a text to words'},
 'unshape': {'action': 'Unshape', 'help': 'unshape arabic letters'},
 'wordtag': {'action': 'Wordtag',
             'help': 'classify words into (nouns, verbs, stopwords)'}
             
  }
def help(command=""):
    """
    display all available commands 
    """
    if command:
        # help for one command
        helpstr = COMMAND_TABLE.get(command,{}).get("help","")
        if not helpstr:
            return ("Error: command '%s' not found"%command)
        else:
            return ("Command: %s : %s"%(command, helpstr))
    else:
        # help for all commands
        lines = []
        max_length = len(max(COMMAND_TABLE.keys(), key=len)) +2
        for command in sorted(COMMAND_TABLE.keys()):
            helpstr =  COMMAND_TABLE.get(command,{}).get("help","")
            lines.append("\t%s: %s"%(command.ljust(max_length), helpstr))
        return u"\n".join(lines)


def DoAction(text, action, options = {}):
    """
    do action by name
    """
    #translate external command string into internal command
    action = COMMAND_TABLE.get(action, {}).get('action', action)
    
    if action == "DoNothing":
        return text
    elif action == "TashkeelText":
        lastmark = options.get('lastmark', "0")
        return tashkeel_text(text, lastmark)
    elif action == "Tashkeel2":
        lastmark = options.get('lastmark', "0")    
        return tashkeel2(text, lastmark)
    elif action == "SpellCheck":
        # lastmark= options.get('lastmark', "0")    
        return spellcheck(text)
    elif action == "CompareTashkeel":
        return compare_tashkeel(text)
    elif action == "ReduceTashkeel":
        return reduced_tashkeel_text(text)
    if action == "Contibute":
        return text
    elif action == "StripHarakat":
        return araby.strip_tashkeel(text)
    elif action == "CsvToData":
        return csv_to_python_table(text)
    elif action == "Romanize":
        return romanize(text)
    elif action == "NumberToLetters":
        return number2letters(text)
    elif action == "LightStemmer":
        lastmark = options.get('lastmark', "0")
        return full_stemmer(text, lastmark)
    elif action == "Tokenize":
        return tokenize(text)
    elif action == "Poetry":
        return justify_poetry(text)
    elif action == "Unshape":
        return pyarabic.unshape.unshaping_text(text)
    elif action == "Affixate":
        return affixate(text)
    elif action == "Normalize":
        return normalize(text)
    elif action == "Wordtag":
        return wordtag(text)
    elif action == "Inverse":
        return inverse(text)
    elif action == "Language":
        return segment_language(text)
    elif action == "RandomText":
        return random_text()
    elif action == "showCollocations":
        return show_collocations(text)
    elif action == "extractEnteties":
        return extract_enteties(text)
    elif action == "extractNamed":
        return extractNamed(text)
    elif action == "chunk":
        return chunksplit(text)
    elif action == "bigrams":
        return bigrams(text)
    elif action == "extractNumbered":
        return extractNumbered(text)       
    else:

        return text


def romanize(text, code = "ISO"):
    """
    Convert Arabic into Latin using a code representaton
    """
    return pyarabic.trans.convert(text,'arabic','tim')

def arabize(text, code = "ISO"):
    """
    Convert Latin to Arabic 
    """
    return pyarabic.trans.convert(text,'tim', 'arabic')

def number2letters(text):
    """
    Convert number to text
    """
    text = text.strip()
    ar = pyarabic.number.ArNumbers()
    return ar.int2str(text)


def light_stemmer(text):
    """
    LightStemming unsing Tashaphyne
    """
    result = []
    als = tashaphyne.stemming.ArabicLightStemmer()
    word_list = als.tokenize(text)
    for word in word_list:
        #~listseg =  als.segment(word)
        als.segment(word)
        affix_list = als.get_affix_list()
        for affix in affix_list:
            result.append({'word':word, 'prefix':affix['prefix'], 
            'stem':affix['stem'], 'suffix':affix['suffix'], 
            'root':affix['root'], 'type':'-'}
                          )
    return result


def full_stemmer(text, lastmark):
    """
    morphological analysis
    """
  
    result = []
    debug = False
    limit = 100
    cpath = os.path.join(os.path.dirname(__file__), '../tmp/')
    analyzer = qalsadi.analex.Analex(cache_path=cpath)
    if lastmark == "0" or not lastmark:
        analyzer.disable_syntax_lastmark()

    anasynt = arasyn.SyntaxAnalyzer()
    anasem = asmai.anasem.SemanticAnalyzer()    
    analyzer.set_debug(debug)
    analyzer.set_limit(limit)
    analyzer.disable_allow_cache_use()    
    mode = 'all'
    result = analyzer.check_text(text)
    #~result, synodelist = anasynt.analyze(result)
    result, __ = anasynt.analyze(result)
    result = anasem.analyze(result)            
    # the result contains objets
    return anasynt.decode(result)


def tokenize(text):
    """
    tokenize a text into words
    """
    return araby.tokenize(text)


def normalize(text):
    """
    normalize a text
    """
    tasha = tashaphyne.stemming.ArabicLightStemmer()
    return tasha.normalize(text)
    
def justify_poetry(text):
    """
    justify a poetry 
    """
    lines = text.splitlines()
    if u'' in lines:
        lines.remove(u"")
    rows = []
    for line in lines:
        partlist = line.strip().split("\t")
        if u'' in partlist:
            partlist.remove(u"")
        if len(partlist) == 2:
            rows.append(partlist)
    return rows


def affixate(text):
    """
    generate all affixed froms from a word
    """
    word_list = tokenize(text)
    if len(word_list) == 0:
        return u''
    else:
        for word in word_list:
            list_gen_words = generate.generate(word)
        return list_gen_words



def wordtag(text):
    """
    word tagginginto noun, verb, tool
    """
    tagger = naftawayh.wordtag.WordTagger()
    word_list = tokenize(text)

    if len(word_list) == 0:
        return []
    else:
        list_result = []
        second_previous =""
        previous = u""
        #~previous_tag  =  ""        
        for word in word_list:
            word_nm = araby.strip_tashkeel(word)
            tag = ''
            if tagger.is_stopword(word):
                tag = 't'
            else:
                if tagger.is_noun(word):
                    tag += 'n'
                if tagger.is_verb(word):
                    tag += 'v'
                if tag in ("", "nv"):
                    tag = tagger.context_analyse(previous, word)+"1"
                    if tag in ("", "nv1", "vn1"):
                        tag = tagger.context_analyse(u" ".join([second_previous, previous]), word)+"2"                    
            list_result.append({'word':word, 'tag': tag})
            second_previous = previous
            previous = word_nm
            #~previous_tag  =  tag
        return list_result


def inverse(text):
    """
    inverse a text
    """
    word_list = tokenize(text)

    if len(word_list) == 0:
        return []
    else:
        list_result = []
        inter_list = []
        for word in word_list:
            inter_list.append(word[::-1])
        inter_list.sort()
        for word in inter_list:
##            result_list.append()
            list_result.append(word[::-1])
        return list_result


def segment_language(text):
    """
    Detect language
    """
    resultlist = []
    if re.search(u"[\u0600-\u06ff]", text[0]):
        arabic = True
    else:
        arabic = False
    actual_text = u""
    for  k in text:
        if re.search(u"[\u0600-\u06ff]", k):
            if arabic:
                actual_text += k
            else:
                resultlist.append(('latin', actual_text))
                arabic = True
                actual_text = k
        elif re.search(u"[\s\d\?, :\!\(\)]", k):
            actual_text += k
        else:
            if arabic:
                i = len(actual_text)
                temp_text = u""
                while not re.search(u"[\u0600-\u06ff]", actual_text[i:i+1]):
                    i -= 1
                temp_text = actual_text[i+1:]
                actual_text = actual_text[:i+1]
                resultlist.append(('arabic', actual_text))
                arabic = False
                actual_text = temp_text+k
            else:
                actual_text += k
    if arabic:
        resultlist.append(('arabic', actual_text))
    else:
        resultlist.append(('latin', actual_text))
    return resultlist


def tashkeel_text(text, lastmark=True):
    """
    Tashkeel text without suggestions
    """
    cpath = os.path.join(os.path.dirname(__file__), '../tmp/')
    vocalizer = ArabicVocalizer.TashkeelClass(mycache_path=cpath)
    #~ print "lastMark", lastmark
    if lastmark == "0":
        vocalizer.disable_last_mark()
    vocalized_text = vocalizer.tashkeel(text)
    return vocalized_text
def reduced_tashkeel_text(text):
    """
    Reduce Harakat and vocalization from a vocalized text.
    @param text: a given vocalized text.
    @type text: unicode.
    @return : reduced text vocalization
    @rtype: unicode
    """
    return araby.reduce_tashkeel(text)

def show_collocations(text):
    """
    Show collocations found in the text.
    The collocations is looked up from a data base extracted from a corpus.
    @param text: a given vocalized text.
    @type text: unicode.
    @return : the text have collocations quoted
    @rtype: unicode
    """
    coll = colloc.CollocationClass(True)
    text = coll.lookup4long_collocations(text)
    wordlist = araby.tokenize(text)
    vocalized_list, taglist = coll.lookup(wordlist)
    #return u" ".join(zip(vocalized_list,taglist))
    text_output = u""
    opened = False
    for word, tag in zip(vocalized_list,taglist):
        if tag in ( "CB", "CI"):
            if not opened:
                text_output += "<mark class='coll'>"
                opened = True   
            text_output += word + " "
        else:
            if opened:
                text_output += "</mark>"
                opened = False
            text_output += word + " "
    return text_output
def extractNamed(text):
    """
    Extract Named Enteties in the text.
    @param text: a given text.
    @type text: unicode.
    @return : the text have Named enteties quoted
    @rtype: unicode
    >>> extractNamed(u"قال خالد بن رافع  حدثني أحمد بن عنبر عن خاله")
    ("خالد بن رافع"، "أحمد بن عنبر ")
    """
    wordlist = araby.tokenize(text)
    taglist = pyarabic.named.detect_named(wordlist)

    text_output = ""
    opened = False
    for word, tag in zip(wordlist, taglist):
        if tag in ("named", 'NI','NB'):
            if not opened:
                text_output += "<mark class='named'>"
                opened = True   
            text_output += word + " "
        else:
            if opened:
                text_output += "</mark>"
                opened = False
            text_output += word + " "
    return text_output


def extract_enteties(text):
    """
    Extract enteties as numbers, named enteties, collocations.
    @param text: a given text.
    @type text: unicode.
    @return : the text have enteties phrases quoted
    @rtype: unicode
    """

    coll = colloc.CollocationClass(True)
    wordlist = araby.tokenize(text)
    taglist_nb = pyarabic.number.detect_numbers(wordlist)
    voclist_nb = pyarabic.number.pre_tashkeel_number(wordlist)
    taglist_nmd = pyarabic.named.detect_named(wordlist)
    voclist_nmd = pyarabic.named.pretashkeel_named(wordlist)
    voclist_coll, taglist_coll = coll.lookup(wordlist)
    # return phrases
    text_output = []
    opened = False
    for word, tagnb, vocnb, tagnmd, vocnmd, tagcol, voccol in zip(wordlist, taglist_nb,voclist_nb, taglist_nmd, voclist_nmd, taglist_coll, voclist_coll):
        if tagnb == 'DB':
            if opened:
                text_output.append("</mark>")
            text_output.extend(["<mark class='number'>",vocnb] )
            opened = True                  
        elif tagnmd == 'NB':
            if opened:
                text_output.append("</mark>")
            text_output.extend(["<mark class='named'>",vocnmd] )
            opened = True  
        elif tagcol =='CB':
            if opened:
                text_output.append("</mark>")
            text_output.extend(["<mark class='coll'>",voccol] )
            opened = True 
        elif tagnmd == "NI":
            text_output.append(vocnmd) 
        elif tagnb == "DI":
            text_output.append(vocnb) 
        elif tagcol == "CI":
            text_output.append(voccol) 
        else:
            if opened:
                 text_output.append("</mark>") 
                 opened = False
            text_output.append(word)
    if opened:
        text_output.append("</mark>")  
    return u" ".join(text_output)


def extract_enteties2(text):
    """
    Extract enteties as numbers, named enteties, collocations.
    @param text: a given text.
    @type text: unicode.
    @return : the text have enteties phrases quoted
    @rtype: unicode
    """
    coll = colloc.CollocationClass(True)
    wordlist = araby.tokenize(text)
    taglist_nb = pyarabic.number.detect_numbers(wordlist)
    taglist_nmd = pyarabic.named.detect_named(wordlist)
    vocalized_list, taglist_coll = coll.lookup(wordlist)
    # return phrases
    text_output = ""
    opened = False
    for word, voc, tagnb, tagnmd, tagcol in zip(wordlist,vocalized_list, taglist_nb, taglist_nmd, taglist_coll):
        if tagnb in ('DI','DB'):
            if not opened:
                text_output += "<mark class='number'>"
                opened = True   
            text_output += word + " "
        elif tagnmd in ('NI','NB'):
            if not opened:
                text_output += "<mark class='named'>"
                opened = True   
            text_output += word + " "
        elif tagcol in ('CI','CB'):
            if not opened:
                text_output += "<mark class='coll'>"
                opened = True   
            text_output += voc + " "           
        else:
            if opened:
                text_output += "</mark>"
                opened = False
            text_output += word + " "
    return text_output
   

def extractNumbered(text):
    """
    Extract number phrases in the text.
    @param text: a given text.
    @type text: unicode.
    @return : the text have number phrases quoted
    @rtype: unicode
    >>> extractNumber(u"وجدت خمسمئة وثلاثة وعشرين دينارا")
    وجدت خمسمئة وثلاثة وعشرين دينارا ")
    """
    wordlist = araby.tokenize(text)
    taglist = pyarabic.number.detect_numbers(wordlist)
    # return phrases
    text_output = ""
    opened = False
    for word, tag in zip(wordlist, taglist):
        if tag in ("named", 'DI','DB'):
            if not opened:
                text_output += "<mark class='number'>"
                opened = True   
            text_output += word + " "
        else:
            if opened:
                text_output += "</mark>"
                opened = False
            text_output += word + " "
    return text_output
    
def tashkeel2(text, lastmark):
    """
    Tashkeel text with suggestions
    """
    cpath = os.path.join(os.path.dirname(__file__), '../tmp/')
    vocalizer = ArabicVocalizer.TashkeelClass(mycache_path = cpath)
    #~ vocalizer.disable_cache()
    if lastmark == "0" or not lastmark:
        vocalizer.disable_last_mark()    
    vocalized_dict = vocalizer.tashkeel_ouput_html_suggest(text)
    return vocalized_dict
    
def spellcheck(text):
    """
    Spellcheck a text
    """
    import spellcheck.spellcheck as ArabicSpellchecker
    cpath = os.path.join(os.path.dirname(__file__), '../tmp/')
    vocalizer = ArabicSpellchecker.SpellcheckClass(cpath)
    #print (u"lastMark %s"%lastmark).encode('utf8')
    vocalized_dict = vocalizer.spellcheckOuputHtmlSuggest(text)
    return vocalized_dict

def compare_tashkeel(text):
    """
    Compare tashkeel between vocalized text and automatic vocalized text
    """
    # the entred text is vocalized correctly
    correct_text = text.strip()
    text = araby.strip_tashkeel(text.strip())
    cpath = os.path.join(os.path.dirname(__file__), '../tmp/')
    vocalizer = ArabicVocalizer.TashkeelClass(mycache_path=cpath)
    #~vocalized_text = vocalizer.tashkeel(text)
    #~ vocalizer.disable_cache()

    vocalized_dict = vocalizer.tashkeel_ouput_html_suggest(text)
    
    # compare voalized text with a correct text
    text1 = correct_text
    #~text2 = vocalized_text
    displayed_html = u""
    
    #stemmer=tashaphyne.stemming.ArabicLightStemmer()
    #~texts = vocalizer.analyzer.split_into_phrases(text1)
    texts = [text1, ]
    list1 =[]
    for txt in texts:
        list1 += vocalizer.analyzer.tokenize(txt)
    list2 = vocalized_dict
    print(u"\t".join(list1)) #.encode('utf8'))
    correct = 0
    incorrect = 0
    total = len(list1)
    if len(list1)!= len(list2):
        print("lists haven't the same length", len(list1), len(list2))
        for i in range(min(len(list1), len(list2))):
            print((u"'%s'\t'%s'"%(list1[i], list2[i].get('chosen',''))))#.encode("utf8"))
        sys.exit()
    else:
        for i in range(total):
            wo1 = list1[i]
            wo1_strip = wo1            
            wo2 = list2[i]['chosen']
            wo2_strip = list2[i]['semi']  # words without inflection mark
            inflect = list2[i]['inflect']
            link = list2[i]['link']
            rule = list2[i]['rule']
            style = "diff"
            #~if araby.is_vocalized(wo2) and araby.vocalizedlike(wo1, wo2):
            if araby.vocalizedlike(wo1, wo2):
                if wo2 == "\n":
                    wo2 = "<br/>"
                #~displayed_html += u" " + wo2
                displayed_html += u" <span id='diff'  class='%s' original='%s' inflect='%s' link='%s' rule='%s'>%s</span>" % ( style, wo1, inflect, link, str(rule), wo2)

                correct += 1
            else:
                incorrect += 1
                # green for last mark difference
                wo1_strip = wo1
                #~wo2_strip = araby.strip_lastharaka(wo2)
                if araby.vocalizedlike(wo1_strip, wo2_strip):
                    style = 'diff-mark'
                else:
                    # if the last marks are equal
                    wm1 = wo1[-1:]
                    wm2 = wo2[-1:]
                    if (araby.is_haraka(wm1) and araby.is_haraka(wm2) and wm1 == wm2) \
                    or (bool(araby.is_haraka(wm1)) ^  bool(araby.is_haraka(wm2))):
                        style = "diff-word"
                    else:
                        style = 'diff-all'
                displayed_html += u" <span id='diff'  class='%s' original='%s' inflect='%s' link='%s' rule='%s'>%s</span>" % ( style, wo1, inflect, link, str(rule), wo2)
    per_correct = round(correct*100.00/total, 2)
    per_incorrect = round(incorrect*100.00/total, 2)
    result = [displayed_html, "correct:%0.2f%%, incorrect:%0.2f%%"%(per_correct, per_incorrect)]
    return result#correct*100/total

def assistanttashkeel(text):
    """
    get tashkeel with suggestions
    """
    cpath = os.path.join(os.path.dirname(__file__), '../tmp/')
    vocalizer = ArabicVocalizer.TashkeelClass(mycache_path=cpath)
    vocalized_text = vocalizer.assistanttashkeel(text)
    return vocalized_text
def random_text():
    """
    get random text for tests
    """    

    
    return random.choice(randtext.textlist)
def chunksplit(text):
    """
    split text into chunks
    """
    # lexical analyzer
    cpath = os.path.join(os.path.dirname(__file__), '../tmp/')
    morphanalyzer = qalsadi.analex.Analex(cache_path=cpath)
    # syntaxic analyzer
    anasynt = arasyn.SyntaxAnalyzer(cache_path=cpath);    
    #~ line =  araby.strip_tashkeel(line);
    #morpholigical analysis of text
    detailled_stem =  morphanalyzer.check_text(text);
    #syntaxical analysis of text
    detailled_syntax, synnodeList =  anasynt.analyze(detailled_stem);
    # print detailled_syntax;
    syno_tags = u" ‫"
    chunklist =[]
    achunk = []
    for synnode in synnodeList:
        if synnode.get_break_type() in ("break", "mostBreak"):
            if synnode.is_break_end():
                achunk.append(synnode.get_word())
                chunklist.append(u" ".join(achunk))
                achunk = []
               #~ print synnode.get_word().encode('utf8');
               #~ print syno_tags.encode('utf8')
                syno_tags = ""
            else:
                chunklist.append(u" ".join(achunk))
                achunk = []
                achunk.append(synnode.get_word())               
               #~ print "break";
               #~ print syno_tags.encode('utf8')
                syno_tags = u" ‫"
               #~ print synnode.get_word().encode('utf8'),                        
        else:
            achunk.append(synnode.get_word())
    if achunk:
        chunklist.append(u" ".join(achunk))
            #print synnode.get_word().encode('utf8'),
        #syno_tags += " '%s[%s]'"%(synnode.get_word_type(), synnode.get_guessed_type_tag())
    return chunklist
def bigrams(text):
    """
    split text into bigrams
    """
    # tokenize texts
    words = araby.tokenize(text)
    bigramslist = []
    for i in range(len(words)-1):
        bigramslist.append(u" ".join([words[i], words[i+1]]))
    counts = Counter(bigramslist)
    bl =[]
    for item in sorted(counts):
        bl.append(u' '.join([item, str(counts[item])]))
    #~ return bigramslist
    return bl



#!/usr/bin/python
# -*- coding=utf-8 -*-
from setuptools import setup

# to install type:
# python setup.py install --root=/
from io import open
def readme():
    with open('README.rst', encoding="utf8") as f:
        return f.read()

setup (name='adawat', version='0.1',
      description="Adawat: Arabic Language Toolkit",
      long_description = readme(),      

      author='Taha Zerrouki',
      author_email='taha.zerrouki@gmail.com',
      url='http://adawat.sourceforge.net/',
      license='GPL',
      package_dir={'adawat': 'adawat'},
      packages=['adawat'],
      install_requires=[ "asmai>=0.1",
                    "mishkal>=0.3",
                    "naftawayh>=0.4",
                    "pyarabic>=0.6.8",
                    "qalsadi>=0.3.6",
                    "repr>=0.3.1",
                    "sylajone>=0.2",
                    "tashaphyne>=0.3.4.1",
            ],         
      include_package_data=True,
      package_data = {
        'aranasyn': ['doc/*.*','doc/html/*', 'data/*.sqlite', 'data/*.sql'],
        },
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Intended Audience :: End Users/Desktop',
          'Operating System :: OS Independent',
          'Programming Language :: Python',
          ],
    );

